FlutterScreenshotDetect class

Constructors

FlutterScreenshotDetect()

Properties

hashCode int
The hash code for this object.
no setterinherited
onScreenshot Stream<FlutterScreenshotEvent>
Represents a screenshot detection event
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Disposes of the screenshot stream
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startListening(dynamic onScreenshotTaken(FlutterScreenshotEvent event)) → void
Starts listening for screenshot events
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited