FlutterScreenshotEvent class

Represents a screenshot detection event with additional metadata

Constructors

FlutterScreenshotEvent({required String method, required DateTime timestamp, String? path})
FlutterScreenshotEvent.fromMap(Map<Object?, Object?> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
method String
The method used to detect the screenshot
final
path String?
Path to the screenshot file (only available for content observer method)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
Timestamp when the screenshot was detected
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited